import java.io.File;
import java.io.IOException;

/**
 * The class SortTest is used to test the threaded and non-threaded
 * sort methods. This program will call each method to sort the data
 * contained in the four test files. This program will then test the
 * results to ensure that the results are sorted in ascending order.
 *
 * Simply run this program to verify that you have correctly implemented
 * the threaded sort method. The program will not verify if your sort
 * uses threads, but will verify if your implementation correctly
 * sorted the data contained in the four files.
 *
 * There should be no reason to make modifications to this class.
 */
public class SortTest {

  public static void main(String[] args) throws IOException {
    File[] files = {new File("enable1.txt"),
            new File("enable2k.txt"),
            new File("lower.txt"),
            new File("mixed.txt")};

    // Run Sort.sort on the files
    long startTime;
    long stopTime;
    
    startTime = System.nanoTime();
    String[] sortedData = Sort.sort(files);
    stopTime = System.nanoTime();
    double elapsedTime = (stopTime - startTime) / 1000000000.0;

    // Test to ensure the data is sorted
    for (int i=0; i<sortedData.length-1; i++) {
      if (sortedData[i].compareTo(sortedData[i+1]) > 0) {
        System.out.println("The data returned by Sort.sort is not sorted.");
        throw new java.lang.IllegalStateException("The data returned by Sort.sort is not sorted");
      }
    }
    System.out.println("The data returned by Sort.sort is sorted.");
    System.out.println("Sort.sort took " + elapsedTime + " seconds to read and sort the data.");

    // Run Sort.threadedSort on the files and test to ensure the data is sorted
    startTime = System.nanoTime();
    String[] threadSortedData = Sort.threadedSort(files);
    stopTime = System.nanoTime();
    double threadedElapsedTime = (stopTime - startTime)/ 1000000000.0;

    // Test to ensure the data is sorted
    if (sortedData.length != threadSortedData.length) {
      System.out.println("The data return by Sort.threadedSort is missing data");
      throw new java.lang.IllegalStateException("The data returned by Sort.threadedSort is not sorted");
    }
    for (int i=0; i<threadSortedData.length-1; i++) {
      if (threadSortedData[i].compareTo(threadSortedData[i+1]) > 0) {
        System.out.println("The data return by Sort.threadedSort is not sorted");
        throw new java.lang.IllegalStateException("The data returned by Sort.threadedSort is not sorted");
      }
    }
    System.out.println("The data returned by Sort.threadedSort is sorted.");
    System.out.println("Sort.threadedSort took " + threadedElapsedTime + " seconds to read and sort the data.");
  }

}